@@ -1,5 +1,5 @@
-from .enums import Color, Icon, ButtonState, TitlePosition
 from .control import Control
+from .enums import ButtonState, Color, Icon, TitlePosition
 
 
 class Button(Control):
@@ -26,13 +26,18 @@ class Button(Control):
         super().__init__("BTTN", control_id, title=title, control_position=control_position, title_position=title_position)
         self._btn_state = ButtonState.OFF
         self.button_enabled = button_enabled
-        self.icon_name = icon_name
+        self._icon_name = icon_name
         self.on_color = on_color
         self.off_color = off_color
         self.text = text
 
     def get_state(self):
-        return self._state_str + f"{self._btn_state.value}\n"
+        text = self._cfg["text"]
+        if (not text) and ( self.icon_name == Icon.NONE):
+            return self._state_str + f"{self._btn_state.value}\n"
+        if (not text) and self.icon_name != Icon.NONE:
+            return self._state_str + f"{self._btn_state.value}\t{self._icon_name.value}\n"
+        return self._state_str + f"{self._btn_state.value}\t{self._icon_name.value}\t{text}\n"
 
     @property
     def button_enabled(self) -> bool:
@@ -87,3 +92,10 @@ class Button(Control):
     def btn_state(self, val: ButtonState):
         self._btn_state = val
         self.state_str = self._state_str + f"{val.value}\n"
+
+    def send_button(self, btn_state: ButtonState, btn_icon: Icon, text: str):
+        self._btn_state = btn_state
+        self._icon_name = btn_icon
+        self._cfg["iconName"] = btn_icon.value
+        self._cfg["text"] = text
+        self.state_str = self._state_str + f"{self._btn_state.value}\t{self._icon_name.value}\t{text}\n"
