@@ -1,8 +1,9 @@
-import logging
-from .event import Event
-from .enums import TitlePosition
-import json
 import copy
+import json
+import logging
+
+from .enums import TitlePosition
+from .event import Event
 
 
 class ControlPosition:
@@ -12,17 +13,19 @@ class ControlPosition:
         self.width_ratio = width_ratio
         self.height_ratio = height_ratio
 
-    def _set_size(self, page_size_x, page_size_y):
-        logging.debug(f"Page X: {page_size_x}, Page Y: {page_size_y}")
+    def set_size(self, page_size_x, page_size_y):
+        logging.debug("Page X: %s, Page Y: %s", page_size_x, page_size_y)
 
 
 class Control:
+
+    """Controls need to implement their own version."""
     def get_state(self) -> str:
         return ""
 
     def get_cfg(self, page_size_x, page_size_y):
         if self.control_position:
-            self.control_position._set_size(page_size_x, page_size_y)
+            self.control_position.set_size(page_size_x, page_size_y)
         cfg_str = "\tCFG\t" + self.msg_type + "\t" + json.dumps(self._cfg) + "\n"
         return cfg_str
 
