@@ -1,5 +1,6 @@
-from .enums import Color, DialNumberPosition, DialStyle, Precision, TitlePosition
 from .control import Control
+from .enums import (Color, DialNumberPosition, DialStyle, Precision,
+                    TitlePosition)
 
 
 class Dial(Control):
@@ -8,8 +9,8 @@ class Dial(Control):
         control_id,
         title="A Dial",
         title_position=TitlePosition.BOTTOM,
-        min=0.0,
-        max=100.0,
+        dial_min=0.0,
+        dial_max=100.0,
         red_value=75.0,
         dial_fill_color=Color.RED,
         pointer_color=Color.BLUE,
@@ -22,8 +23,8 @@ class Dial(Control):
     ):
         super().__init__("DIAL", control_id, title=title, control_position=control_position, title_position=title_position)
         self._dial_value = 0
-        self.min = min
-        self.max = max
+        self.dial_min = dial_min
+        self.dial_max = dial_max
         self.red_value = red_value
         self.dial_fill_color = dial_fill_color
         self.pointer_color = pointer_color
@@ -46,19 +47,19 @@ class Dial(Control):
         self.state_str = self._state_str + f"{val}\n"
 
     @property
-    def min(self) -> float:
+    def dial_min(self) -> float:
         return self._cfg["min"]
 
-    @min.setter
-    def min(self, val: float):
+    @dial_min.setter
+    def dial_min(self, val: float):
         self._cfg["min"] = val
 
     @property
-    def max(self) -> float:
+    def dial_max(self) -> float:
         return self._cfg["max"]
 
-    @max.setter
-    def max(self, val: float):
+    @dial_max.setter
+    def dial_max(self, val: float):
         self._cfg["max"] = val
 
     @property
