@@ -1,10 +1,11 @@
-from .enums import Color, TitlePosition
-from .control import Control
-from .ring_buffer import RingBuffer
-
 import datetime
+
 import dateutil.parser
 
+from .control import Control
+from .enums import Color, TitlePosition
+from .ring_buffer import RingBuffer
+
 
 class EventData:
     def __init__(self, header, body, color=Color.WHITE):
@@ -31,14 +32,14 @@ class EventLog(Control):
                  title_position=TitlePosition.BOTTOM,
                  control_position=None, max_log_entries=100):
         super().__init__("LOG", control_id, title=title, control_position=control_position, title_position=title_position)
-        self.message_rx_event = self.__get_log_from_timestamp
+        self.message_rx_event = self._get_log_from_timestamp
         self.log = RingBuffer(max_log_entries)
 
-    def __get_log_from_timestamp(self, msg):
-        dt = dateutil.parser.isoparse(msg[3])
+    def _get_log_from_timestamp(self, msg):
+        log_date = dateutil.parser.isoparse(msg[3])
         data_str = ""
         for log in self.log.get():
-            if log.timestamp > dt:
+            if log.timestamp > log_date:
                 data_str += self._state_str + log.to_string()
         self.state_str = data_str
 
