@@ -1,13 +1,14 @@
-from .slider_single_bar import SliderSingleBar
 from .enums import Color, SliderBarType, TitlePosition
+from .slider_single_bar import SliderSingleBar
+
 
 class SliderDoubleBar(SliderSingleBar):
     def __init__(self,
                  control_id,
                  title="A Single Slider",
                  title_position=TitlePosition.BOTTOM,
-                 min=0.0,
-                 max=1000.0,
+                 bar_min=0.0,
+                 bar_max=1000.0,
                  red_value=750,
                  show_min_max=False,
                  slider_enabled=True,
@@ -20,8 +21,8 @@ class SliderDoubleBar(SliderSingleBar):
         super().__init__(control_id,
                          title,
                          title_position,
-                         min,
-                         max,
+                         bar_min,
+                         bar_max,
                          red_value,
                          show_min_max,
                          slider_enabled,
